==> vue-watermark-2.23.0.tgz: package/lib/index.js <==
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/watermark/vue';
import '@opentinyvue/vue-theme/watermark/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var $constants = {
  font: {
    color: "rgba(0,0,0,.15)",
    fontSize: 16,
    fontWeight: "normal",
    fontFamily: "sans-serif",
    fontStyle: "normal"
  }
};
var __vue2_script = defineComponent({
  name: $prefix + "Watermark",
  props: {
    _constants: {
      type: Object,
      default: function _default() {
        return $constants;
      }
    },
    width: {
      type: Number,
      default: 120
    },
    height: {
      type: Number,
      default: 64
    },
    rotate: {
      type: Number,
      default: -22
    },
    zIndex: {
      type: Number,
      default: 9
    },
    image: {
      type: String
    },
    content: {
      type: [String, Array]
    },
    font: {
      type: Object
    },
    gap: {
      type: Array,
      default: [100, 100]
    },
    offset: {
      type: Array,
      default: [20, 20]
    },
    customClass: {
      type: String,
      default: ""
    },
    interlaced: {
      type: Boolean,
      default: true
    }
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      mono: true,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    ref: "parentRef",
    staticClass: "tiny-watermark-wrapper"
  }, [_vm._t("default")], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var Watermark = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.23.0";
Watermark.install = function(Vue) {
  Vue.component(Watermark.name, Watermark);
};
Watermark.version = version;

export { Watermark as default };

==> vue-watermark-2.24.0.tgz: package/lib/index.js <==
import { defineComponent, $prefix, setup } from '@opentinyvue/vue-common';
import { renderless, api } from '@opentinyvue/vue-renderless/watermark/vue';
import '@opentinyvue/vue-theme/watermark/index.css';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var $constants = {
  font: {
    color: "rgba(0,0,0,.15)",
    fontSize: 16,
    fontWeight: "normal",
    fontFamily: "sans-serif",
    fontStyle: "normal"
  }
};
var __vue2_script = defineComponent({
  name: $prefix + "Watermark",
  props: {
    _constants: {
      type: Object,
      default: function _default() {
        return $constants;
      }
    },
    width: {
      type: Number,
      default: 120
    },
    height: {
      type: Number,
      default: 64
    },
    rotate: {
      type: Number,
      default: -22
    },
    zIndex: {
      type: Number,
      default: 9
    },
    image: {
      type: String
    },
    content: {
      type: [String, Array]
    },
    font: {
      type: Object
    },
    gap: {
      type: Array,
      default: [100, 100]
    },
    offset: {
      type: Array,
      default: [20, 20]
    },
    customClass: {
      type: String,
      default: ""
    },
    interlaced: {
      type: Boolean,
      default: true
    }
  },
  setup: function setup$1(props, context) {
    return setup({
      props,
      context,
      renderless,
      mono: true,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    ref: "parentRef",
    staticClass: "tiny-watermark-wrapper"
  }, [_vm._t("default")], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var Watermark = /* @__PURE__ */ function() {
  return __component__.exports;
}();
var version = "2.undefined";
Watermark.install = function(Vue) {
  Vue.component(Watermark.name, Watermark);
};
Watermark.version = version;

export { Watermark as default };
